#
# spec file for package gtkhash
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gtkhash
Version:        1.5
Release:        bp156.4.3.1
Summary:        GTK+ utility for computing message digests or checksums
License:        GPL-2.0-or-later
Group:          Productivity/File utilities
URL:            https://gtkhash.org
Source0:        https://github.com/tristanheaven/%{name}/releases/download/v%{version}/%{name}-%{version}.tar.xz
BuildRequires:  hicolor-icon-theme
BuildRequires:  intltool
# 13.2 and Leap 42.1/2 have too old versions
%if 0%{?suse_version} > 1320
BuildRequires:  libgcrypt-devel >= 1.7
%endif
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(nettle)
BuildRequires:  rsvg-convert
### not pkgconfig(thunarx-[23]), because we don't know in advance
BuildRequires:  thunar-devel
%glib2_gsettings_schema_requires
%lang_package

%description
GtkHash is a GTK+ utility for computing message digests or checksums.
Currently supported hash functions include:

* MD2, MD4, MD5, MD6-224, MD6-256, MD6-384, MD6-512
* SHA1, SHA224, SHA256, SHA384, SHA512
* SHA3-224, SHA3-256, SHA3-384, SHA3-512
* RIPEMD128, RIPEMD160, RIPEMD256, RIPEMD320
* TIGER192, WHIRLPOOL, GOST, CRC32, ADLER32

This package contains the GTK+3 version of the program.

%package -n thunar-plugin-gtkhash
Summary:        GtkHash extension for Thunar
Group:          System/GUI/XFCE
Requires:       %{name} = %{version}
Requires:       thunar

%description -n thunar-plugin-gtkhash
GtkHash extension for the Thunar file manger. It adds an additional tab
called "Digests" to the file properties dialog.

%prep
%setup -q

%build
%configure \
%if 0%{?suse_version} >= 1500
    --with-thunarx=3 \
%else
    --with-thunarx=2 \
%endif
    --with-gtk=3.0 \
    --disable-blake2 \
%if 0%{?suse_version} && 0%{?suse_version} < 1330
    --disable-gcrypt \
%endif
    --enable-glib-checksums \
    --enable-linux-crypto \
    --enable-nettle \
    --enable-thunar \
    --disable-schemas-compile

%make_build

%install
%make_install
rm %{buildroot}%{_libdir}/thunarx-?/libgtkhash-properties-thunar.la

%find_lang %{name} %{?no_lang_C}
%suse_update_desktop_file org.gtkhash.%{name}

%if 0%{?suse_version} && 0%{?suse_version} < 1330
%post
%glib2_gsettings_schema_post
%icon_theme_cache_post

%postun
%glib2_gsettings_schema_postun
%icon_theme_cache_postun

%post -n thunar-plugin-gtkhash
%glib2_gsettings_schema_post

%postun -n thunar-plugin-gtkhash
%glib2_gsettings_schema_postun
%endif

%files
%license COPYING
%doc AUTHORS NEWS README.md
%{_bindir}/%{name}
%{_datadir}/applications/org.%{name}.%{name}.desktop
%{_datadir}/glib-2.0/schemas/org.gtkhash.gschema.xml
%{_datadir}/icons/hicolor/*/*/org.%{name}.%{name}.*
%if 0%{?suse_version} && 0%{?suse_version} < 1500
%dir %{_datadir}/metainfo/
%endif
%{_datadir}/metainfo/org.%{name}.%{name}.appdata.xml

%files -n thunar-plugin-gtkhash
%{_datadir}/glib-2.0/schemas/org.gtkhash.plugin.gschema.xml
%{_libdir}/thunarx-?/libgtkhash-properties-thunar.so
%{_datadir}/metainfo/org.gtkhash.thunar.metainfo.xml

%files lang -f %{name}.lang

%changelog
* Mon Sep 26 2022 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.5
  * Added xxHash XXH64
  * Added HMAC-BLAKE2s and HMAC-BLAKE2b (gh#tristanheaven/gtkhash#86)
  * Made hashing start automatically in file manager extensions
    (gh#tristanheaven/gtkhash#103)
  * Added Meson build system (gh#tristanheaven/gtkhash#116,
    gh#tristanheaven/gtkhash#140)
  * Removed dependency on intltool
  * Removed Peony extension as Peony 2+ is incompatible
* Thu Oct  7 2021 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.4
  * Fixed crash when program is closed (gh#tristanheaven/gtkhash#47)
  * Added vertical scrolling to File/Text view
    (gh#tristanheaven/gtkhash#35)
  * Added clipboard paste button to Check input
  * Added Windows compatibility
  * Removed support for GTK 2
  * Added CRC32C
  * Replaced the word "Digest" with "Checksum" in some places
    (gh#tristanheaven/gtkhash#40)
  * Added a separate hash button for each function
    (gh#tristanheaven/gtkhash#50)
  * Added preference to show/hide HMAC feature
  * Fixed translations not showing on Windows and Snap package
  * Reduced Windows install size
* Thu Jan 30 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Sun Jan  6 2019 Kyrill Detinov <lazy.kent@opensuse.org>
- Update to 1.2.
  * Added compatibility for Thunar 1.7.
- Remove hack and use the "--with-thunarx=3" configure option for
  Leap 15 and newer.
* Sun Sep  2 2018 Stefan Seyfried <seife+obs@b1-systems.com>
- add specfile hack to fix build with thunarx-3
* Tue Apr 10 2018 lazy.kent@opensuse.org
- Update to 1.1.1.
  * Fixed bug in loading user preferences.
- Changes in 1.1.
  * Removed internal BLAKE2 code and added option to use libb2
    instead.
  * Removed PolarSSL support (replaced by mbed TLS).
- Changes in 1.0.1.
  * Fixed crash when certain Linux kernel crypto modules aren't
    loaded.
  * Fixed plugin crash when viewing file properties in Thunar.
  * Other bug fixes.
- Correct the source URL.
- Remove the gtkhash.svg icon (included in tarball).
- Remove BuildRequires: pkgconfig(libcrypto) (no need).
- Correct the list of supported hash functions in description.
- Disable BLAKE2 function (nothing provides libb2).
- Use the original desktop file.
* Mon Dec 26 2016 seife+obs@b1-systems.com
- 13.2 also has too old gcrypt
* Sun Dec 25 2016 seife+obs@b1-systems.com
- only enable gcrypt on distributions that have new enough packages
* Sun Dec 25 2016 seife+obs@b1-systems.com
- update to version 1.0
- build with gtk3
- do not run autoconf
- package appdata stuff
- verbose build to allow rpmlint checks to work
* Sat Feb 13 2016 lazy.kent@opensuse.org
- Initial package created - 0.7.0.
